@@ -4,7 +4,8 @@ use warnings;
 use Path::Tiny;
 use Cwd;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
+my $root;
 
 sub import
 {
@@ -42,6 +43,7 @@ sub import
 
   if ( $found )
   {
+    $root = $found->parent;
     push @INC, glob $lib_paths;
     $callback->( $lib_paths, $found )
       if $callback;
@@ -53,6 +55,11 @@ sub import
   }
 }
 
+sub root
+{
+  return $root;
+}
+
 1;
 
 __END__
@@ -67,7 +74,7 @@ lib::root - find perl root and push lib modules path to @INC
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -212,7 +219,7 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Hernan Lopes E<lt>hernan@smallcompany.netE<gt>
+Hernan Lopes
 
 =cut
 
